@@ -130,7 +130,7 @@ def calculate_md5(params, **kwargs):
     request_dict = params
     if request_dict['body'] and 'Content-MD5' not in params['headers']:
         body = request_dict['body']
-        if isinstance(body, bytes):
+        if isinstance(body, (bytes, bytearray)):
             binary_md5 = _calculate_md5_from_bytes(body)
         else:
             binary_md5 = _calculate_md5_from_file(body)
@@ -386,7 +386,8 @@ def copy_snapshot_encrypted(params, request_signer, **kwargs):
     request_dict_copy['method'] = 'GET'
     request_dict_copy['headers'] = {}
     presigned_url = request_signer.generate_presigned_url(
-        request_dict_copy, region_name=source_region)
+        request_dict_copy, region_name=source_region,
+        operation_name='CopySnapshot')
     params['PresignedUrl'] = presigned_url
 
 
